summaryrefslogtreecommitdiffstats
path: root/umbrello/umbrello/dialogs/selectopdlg.h
diff options
context:
space:
mode:
Diffstat (limited to 'umbrello/umbrello/dialogs/selectopdlg.h')
-rw-r--r--umbrello/umbrello/dialogs/selectopdlg.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/umbrello/umbrello/dialogs/selectopdlg.h b/umbrello/umbrello/dialogs/selectopdlg.h
index 3c12b1b1..be8a38ad 100644
--- a/umbrello/umbrello/dialogs/selectopdlg.h
+++ b/umbrello/umbrello/dialogs/selectopdlg.h
@@ -44,10 +44,10 @@ public:
/**
* Constructs a SelectOpDlg instance.
*
* @param tqparent The tqparent to this instance.
* @param c The concept to get the operations from.
*/
- SelectOpDlg(UMLView * tqparent, UMLClassifier * c);
+ SelectOpDlg(UMLView * parent, UMLClassifier * c);
/**
* Standard deconstructor.
@@ -44,10 +44,10 @@ public:
* Constructs a SelectOpDlg instance.
*
- * @param tqparent The tqparent to this instance.
+ * @param parent The parent to this instance.
* @param c The concept to get the operations from.
*/